==> aws_cdk.aws_refactorspaces-1.157.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_refactorspaces_CfnApplicationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.apiGatewayProxy))
            _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty(p.apiGatewayProxy);
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnApplication(p) {
}
function _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnEnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnEnvironment(p) {
}
function _aws_cdk_aws_refactorspaces_CfnRouteProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnRoute(p) {
}
function _aws_cdk_aws_refactorspaces_CfnRoute_UriPathRouteInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnServiceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnService(p) {
}
function _aws_cdk_aws_refactorspaces_CfnService_LambdaEndpointInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnService_UrlEndpointInputProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_refactorspaces_CfnApplicationProps, _aws_cdk_aws_refactorspaces_CfnApplication, _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty, _aws_cdk_aws_refactorspaces_CfnEnvironmentProps, _aws_cdk_aws_refactorspaces_CfnEnvironment, _aws_cdk_aws_refactorspaces_CfnRouteProps, _aws_cdk_aws_refactorspaces_CfnRoute, _aws_cdk_aws_refactorspaces_CfnRoute_UriPathRouteInputProperty, _aws_cdk_aws_refactorspaces_CfnServiceProps, _aws_cdk_aws_refactorspaces_CfnService, _aws_cdk_aws_refactorspaces_CfnService_LambdaEndpointInputProperty, _aws_cdk_aws_refactorspaces_CfnService_UrlEndpointInputProperty };

==> aws_cdk.aws_refactorspaces-1.184.0-py3-none-any.whl: package/.warnings.jsii.js <==
function _aws_cdk_aws_refactorspaces_CfnApplicationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.apiGatewayProxy))
            _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty(p.apiGatewayProxy);
        if (p.tags != null)
            for (const o of p.tags)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnApplication(p) {
}
function _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnEnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.tags != null)
            for (const o of p.tags)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnEnvironment(p) {
}
function _aws_cdk_aws_refactorspaces_CfnRouteProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.tags != null)
            for (const o of p.tags)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnRoute(p) {
}
function _aws_cdk_aws_refactorspaces_CfnRoute_DefaultRouteInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnRoute_UriPathRouteInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnServiceProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.tags != null)
            for (const o of p.tags)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_refactorspaces_CfnService(p) {
}
function _aws_cdk_aws_refactorspaces_CfnService_LambdaEndpointInputProperty(p) {
}
function _aws_cdk_aws_refactorspaces_CfnService_UrlEndpointInputProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_refactorspaces_CfnApplicationProps, _aws_cdk_aws_refactorspaces_CfnApplication, _aws_cdk_aws_refactorspaces_CfnApplication_ApiGatewayProxyInputProperty, _aws_cdk_aws_refactorspaces_CfnEnvironmentProps, _aws_cdk_aws_refactorspaces_CfnEnvironment, _aws_cdk_aws_refactorspaces_CfnRouteProps, _aws_cdk_aws_refactorspaces_CfnRoute, _aws_cdk_aws_refactorspaces_CfnRoute_DefaultRouteInputProperty, _aws_cdk_aws_refactorspaces_CfnRoute_UriPathRouteInputProperty, _aws_cdk_aws_refactorspaces_CfnServiceProps, _aws_cdk_aws_refactorspaces_CfnService, _aws_cdk_aws_refactorspaces_CfnService_LambdaEndpointInputProperty, _aws_cdk_aws_refactorspaces_CfnService_UrlEndpointInputProperty };
